antares.apps.user.templatetags package — Antares 0.0.2 documentation

# antares.apps.user.templatetags package

## Submodules

## antares.apps.user.templatetags.auth_tags module

Created on 28 sep. 2016

@author: leobelen

`antares.apps.user.templatetags.auth_tags.` `draw_site_menu`(context)

`antares.apps.user.templatetags.auth_tags.` `draw_site_nav`(context)

`antares.apps.user.templatetags.auth_tags.` `on_behalf_selector`(context)

`antares.apps.user.templatetags.auth_tags.` `process_site_menu_app`(app)

`antares.apps.user.templatetags.auth_tags.` `process_site_nav`(app)

## Module contents